#line 2 "scanner.c"

#line 4 "scanner.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart (FILE *input_file  );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,int len  );

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *yyin = (FILE *) 0, *yyout = (FILE *) 0;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 94
#define YY_END_OF_BUFFER 95
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_acclist[529] =
    {   0,
       95,   94,    3,   94,    4,   94,    4,   94,   94,   94,
       94,   29,   94,   18,   94,   19,   94,   26,   94,   24,
       94,   14,   94,   25,   94,   27,   94,   91,   94,   91,
       94,   15,   94,   94,   94,   94,   94,   93,   94,   16,
       94,   17,   94,   30,   94,   93,   94,   93,   94,   93,
       94,   93,   94,   93,   94,   93,   94,   93,   94,   93,
       94,   93,   94,   93,   94,   93,   94,   93,   94,   28,
       94,   31,   94,   94,    3,   94,    1,    4,   94,    4,
       94,   94,   94,   94,   29,   94,   18,   94,   19,   94,
       26,   94,   24,   94,   14,   94,   25,   94,   94,   27,

       94,   91,   94,   91,   94,   15,   94,   94,   94,   94,
       94,   93,   94,   16,   94,   17,   94,   30,   94,   93,
       94,   93,   94,   93,   94,   93,   94,   93,   94,   93,
       94,   93,   94,   93,   94,   93,   94,   93,   94,   93,
       94,   93,   94,   28,   94,   31,   94,    3,    4,   21,
       23,   91,   32,   20,   33,   89,   93,   92,   93,   93,
       93,   93,   59,   93,   67,   93,   65,   93,   93,   93,
       57,   93,   93,   93,   93,   93,   93,   93,   43,   93,
       93,   11,   93,   11,   93,   11,   93,   93,   93,   49,
       93,   50,   93,   93,   48,   93,   93,   46,   93,   93,

       93,   93,   93,   22,    1,    3,    1,    4,   21,   23,
       91,   32,   20,   33,   89,   93,   92,   93,   93,   93,
       93,   59,   93,   67,   93,   65,   93,   93,   93,   57,
       93,   93,   93,   93,   93,   93,   93,   43,   93,   93,
       11,   93,   11,   93,   11,   93,   93,   93,   49,   93,
       50,   93,   93,   48,   93,   93,   46,   93,   93,   93,
       93,   93,   22,   90,   89,   34,   93,   44,   93,   93,
       93,   93,   66,   93,   63,   93,   68,   93,   61,   93,
       54,   93,   93,   60,   93,   58,   93,   93,   69,   93,
       13,   93,   93,   53,   93,   93,   81,   93,   93,   52,

       93,   84,   93,   93,   75,   93,   93,   93,   42,   93,
       47,   93,   38,   93,   93,   93,   45,   93,   90,   89,
       34,   93,   44,   93,   93,   93,   93,   66,   93,   63,
       93,   68,   93,   61,   93,   54,   93,   93,   60,   93,
       58,   93,   93,   69,   93,   13,   93,   93,   53,   93,
       93,   81,   93,   93,   52,   93,   84,   93,   93,   75,
       93,   93,   93,   42,   93,   47,   93,   38,   93,   93,
       93,   45,   93,   89,   35,   36,   93,   73,   93,   55,
       93,   71,   93,   62,   93,   64,   93,   93,   93,   70,
       93,   93,   51,   93,   12,   93,   93,   76,   93,   93,

       93,   10,   93,   39,   40,   93,   93,   88,   93,   89,
       35,   36,   93,   73,   93,   55,   93,   71,   93,   62,
       93,   64,   93,   93,   93,   70,   93,   93,   51,   93,
       12,   93,   93,   76,   93,   93,   93,   10,   93,   39,
       40,   93,   93,   88,   93,   89,   37,   74,   93,   56,
       93,   72,   93,   93,   93,   85,   93,   86,   93,   87,
       93,   10,   93,   41,   77,   93,   79,   93,    5,   89,
       37,   74,   93,   56,   93,   72,   93,   93,   93,   85,
       93,   86,   93,   87,   93,   10,   93,   41,   77,   93,
       79,   93,   82,   93,   83,   93,   10,   93,   78,   93,

       80,   93,    6,    1,    8,   82,   93,   83,   93,   10,
       93,   78,   93,   80,   93,    2,    2,    7,   10,   93,
        1,    2,    2,    7,   10,   93,16393, 8201
    } ;

static yyconst flex_int16_t yy_accept[399] =
    {   0,
        1,    1,    1,    2,    3,    5,    7,    9,   10,   11,
       12,   14,   16,   18,   20,   22,   24,   26,   28,   30,
       32,   34,   35,   36,   37,   38,   40,   42,   44,   46,
       48,   50,   52,   54,   56,   58,   60,   62,   64,   66,
       68,   70,   72,   74,   75,   77,   80,   82,   83,   84,
       85,   87,   89,   91,   93,   95,   97,   99,  100,  102,
      104,  106,  108,  109,  110,  111,  112,  114,  116,  118,
      120,  122,  124,  126,  128,  130,  132,  134,  136,  138,
      140,  142,  144,  146,  148,  149,  150,  151,  151,  151,
      151,  152,  153,  153,  154,  155,  156,  157,  158,  159,

      160,  161,  162,  163,  165,  167,  169,  170,  171,  173,
      174,  175,  176,  177,  178,  179,  181,  182,  184,  186,
      188,  189,  190,  192,  194,  195,  197,  198,  200,  201,
      202,  203,  204,  205,  205,  206,  207,  207,  207,  209,
      210,  210,  210,  210,  210,  211,  212,  212,  212,  212,
      213,  214,  215,  216,  217,  218,  219,  220,  221,  222,
      224,  226,  228,  229,  230,  232,  233,  234,  235,  236,
      237,  238,  240,  241,  243,  245,  247,  248,  249,  251,
      253,  254,  256,  257,  259,  260,  261,  262,  263,  264,
      264,  264,  265,  266,  268,  270,  271,  272,  273,  275,

      277,  279,  281,  283,  284,  286,  288,  289,  291,  293,
      294,  296,  297,  299,  300,  302,  304,  305,  307,  308,
      309,  311,  313,  315,  316,  317,  319,  319,  319,  319,
      319,  319,  319,  319,  319,  320,  321,  323,  325,  326,
      327,  328,  330,  332,  334,  336,  338,  339,  341,  343,
      344,  346,  348,  349,  351,  352,  354,  355,  357,  359,
      360,  362,  363,  364,  366,  368,  370,  371,  372,  374,
      374,  374,  375,  376,  378,  380,  382,  384,  386,  388,
      389,  390,  392,  393,  395,  397,  398,  400,  401,  402,
      404,  405,  407,  408,  410,  410,  410,  410,  410,  410,

      410,  411,  412,  414,  416,  418,  420,  422,  424,  425,
      426,  428,  429,  431,  433,  434,  436,  437,  438,  440,
      441,  443,  444,  446,  446,  446,  447,  448,  450,  452,
      454,  455,  456,  458,  460,  462,  464,  465,  467,  469,
      469,  470,  470,  470,  470,  470,  471,  472,  474,  476,
      478,  479,  480,  482,  484,  486,  488,  489,  491,  493,
      493,  493,  493,  495,  497,  499,  501,  503,  503,  503,
      503,  504,  504,  504,  506,  508,  510,  512,  514,  516,
      516,  517,  518,  519,  521,  521,  523,  524,  525,  525,
      527,  527,  528,  528,  528,  529,  529,  529

    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    5,    6,    7,    1,    8,    9,    1,   10,
       11,   12,   13,   14,   15,   16,   17,   18,   19,   20,
       21,   22,   22,   23,   24,   24,   24,   25,   26,   27,
       28,   29,    1,   30,   31,   31,   31,   31,   31,   31,
       32,   32,   32,   32,   32,   32,   32,   32,   32,   32,
       32,   32,   32,   32,   32,   32,   32,   32,   32,   32,
       33,    1,   34,   35,   32,    1,   36,   37,   38,   39,

       40,   41,   42,   43,   44,   45,   46,   47,   48,   49,
       50,   51,   32,   52,   53,   54,   55,   56,   32,   57,
       58,   59,    1,   60,    1,   61,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[62] =
    {   0,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    3,    3,    3,
        3,    3,    3,    3,    4,    1,    1,    1,    1,    1,
        3,    4,    1,    1,    1,    3,    3,    3,    3,    3,
        3,    4,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4,    4,    1,
        1
    } ;

static yyconst flex_int16_t yy_base[407] =
    {   0,
        0,   61, 1135, 1136, 1132, 1136, 1130, 1104, 1123,  121,
     1023, 1136, 1136, 1136, 1136, 1136,  106, 1136,  113,  120,
     1136, 1004, 1002,  998,    0, 1001, 1136, 1136, 1136,  120,
      122,  124,  123,  126,  125,  127,  137,  166,  153,  157,
      131,  965, 1136, 1021,  191, 1136, 1020,  164,  151,  195,
      192, 1019, 1018, 1017, 1016, 1015,  214,  207, 1014,  221,
      244, 1013,  219,  222,  220,  276,  317, 1012, 1011, 1010,
      116,  976,  233,  959,  164,  974,  174,  966,  361,  343,
      175,  958,  160, 1004, 1004, 1136, 1136,  397,  217,  952,
     1136,  236,    0, 1136, 1136, 1136,    0,  979, 1136,  191,

      245,  227,  252,  246,  251,  371,  258,  387,  978,  368,
      384,  262,  366,  381,  247,  382,  375,  977,  429,  365,
      389,  401,  976,  967,  260,  966,  385,  406,  265,  413,
      409,  404, 1136,  987, 1136,  456,  433,  438, 1136,  986,
      475,  464,  457,  389,  985,  484,  441,  471,  500,  984,
      983,  982,  524,    0,  981,  944,  943,  933,  920,  911,
      422,  428,  916,  476,    0,  909,  507,  921,  908,  422,
      922,  905,  903,    0,  548,  531,  921,  905,    0,    0,
      909,    0,  895,  253,  909,  901,  908,  890,  938,  555,
      887,    0,    0,  445,  914,  454,  555,  459,  505,  913,

      528,  912,  897,  440,  529,  896,  531,  895,  894,  509,
      893,  557,  892,  579,  891,  890,  489,  558,  566,  594,
      889,  888,  568,  570,  578,  887,  587,  589,  625,  477,
      602,  606,  488,  604,    0,  644,  613,    0,  863,  861,
      845,  845,    0,  844,    0,    0,  846,  837,    0,  836,
        0,    0,  842,    0,  852,    0,  651,    0,    0,  846,
      822,  589,  668,    0,    0,  620,  823,  825,    0,  618,
      832,    0, 1136,  460,  597,  846,  845,  844,  843,  613,
      668,  842,  635,  841,  840,  628,  838,  614,  675,  705,
     1136,  678,  654,  828,  708,  616,  673,  695,  699,  709,

      746,  849,  835,  797,    0,    0,    0,    0,  809,  793,
        0,  696,    0,    0,  796,    0,  822,  824,  770,  840,
      813,  673,    0,  822,  775, 1136, 1136,  801,  798,  797,
      696,  710,  796,  795,  794,  794, 1136,  706,  707,  731,
      802,  745,  746,  715,  226,  801,  799,    0,    0,    0,
      776,  778,    0,    0,    0,  818,  793,  742,  728,  774,
      858,  725,  753,  750,  865,  737,  713,  748,  905,  749,
      730,  736,  753, 1136,    0,    0,  912,    0,    0,  952,
     1136,  755, 1136,  652,  975, 1136,  770,  654,  693,    0,
      771,  747,  997, 1056,  485,    0, 1136,  308, 1115, 1119,

      302,  290,  208,  143, 1123, 1127
    } ;

static yyconst flex_int16_t yy_def[407] =
    {   0,
      397,  397,  397,  397,  397,  397,  397,  397,  397,  397,
      397,  397,  397,  397,  397,  397,  397,  397,  397,  397,
      397,  397,  397,  397,  398,  399,  397,  397,  397,  399,
      399,  399,  399,  399,  399,  399,  399,  399,  399,  399,
      399,  397,  397,  400,  400,  397,  400,  400,  400,  400,
      400,  400,  400,  400,  400,  400,  400,  400,  400,  400,
      400,  400,  400,  400,  400,  400,  397,  400,  400,  400,
       67,   67,   67,   67,   67,   67,   67,   67,   67,   67,
       67,   67,  400,  400,  397,  397,  397,  397,  397,  397,
      397,  397,  401,  397,  397,  397,  402,  399,  397,  399,

      399,  399,  399,  399,  399,  399,  399,  399,  399,  399,
      399,  399,  399,  399,  399,  399,  399,  399,  399,  119,
      399,  399,  399,  399,  399,  399,  399,  399,  399,  399,
      399,  399,  397,  400,  397,  400,  400,  400,  397,  400,
      400,  400,  400,  400,  400,  400,  400,  400,   66,  400,
      400,  400,   66,   67,  400,   67,   67,   67,   67,   67,
       67,   67,   67,   67,   67,   67,   67,   67,   67,   67,
       67,   67,   67,   67,   67,   67,   67,   67,   67,   67,
       67,   67,   67,   67,   67,   67,   67,   67,  400,  397,
      397,  401,  403,  399,  399,  399,  399,  399,  399,  399,

      399,  399,  399,  399,  399,  399,  399,  399,  399,  399,
      399,  399,  399,  399,  399,  399,  399,  399,  399,  214,
      399,  399,  399,  399,  399,  399,  400,  400,  400,  400,
      400,  400,  400,  400,  149,  149,   67,   67,   67,   67,
       67,   67,   67,   67,   67,   67,   67,   67,   67,   67,
       67,   67,   67,   67,   67,   67,   67,   67,   67,   67,
       67,   67,   67,   67,   67,   67,   67,   67,   67,  397,
      397,  404,  397,  399,  399,  399,  399,  399,  399,  399,
      399,  399,  399,  399,  399,  399,  399,  399,  399,  214,
      397,  399,  399,  399,  400,  400,  400,  400,  400,  400,

      149,  400,   67,   67,   67,   67,   67,   67,   67,   67,
       67,   67,   67,   67,   67,   67,   67,   67,   67,  400,
       67,   67,   67,  405,  397,  397,  397,  399,  399,  399,
      399,  399,  399,  399,  399,  214,  397,  399,  399,  406,
      400,  400,  400,  400,  400,  400,  400,   67,   67,   67,
       67,   67,   67,   67,   67,   67,  400,   67,   67,  405,
      405,  397,  399,  399,  214,  399,  399,  406,  406,  400,
      400,  400,  400,  397,   67,   67,   67,   67,   67,  405,
      397,  405,  397,  399,  406,  397,  406,  400,  400,   67,
      400,  400,  400,  397,  400,  394,    0,  397,  397,  397,

      397,  397,  397,  397,  397,  397
    } ;

static yyconst flex_int16_t yy_nxt[1198] =
    {   0,
        4,    5,    6,    7,    8,    4,    9,   10,   11,   12,
       13,   14,   15,   16,   17,    4,   18,   19,   20,   20,
       20,   20,   20,   20,    4,   21,   22,   23,   24,   25,
       26,   26,   27,   28,   29,   30,   26,   31,   26,   26,
       26,   26,   26,   26,   32,   26,   33,   34,   35,   36,
       37,   38,   39,   40,   26,   26,   41,   26,   26,   42,
       43,   44,   45,   46,   47,   48,   44,   49,   50,   51,
       52,   53,   54,   55,   56,   57,   58,   59,   60,   61,
       61,   61,   61,   61,   61,   44,   62,   63,   64,   65,
       66,   67,   67,   68,   69,   70,   71,   67,   72,   67,

       67,   67,   67,   67,   67,   73,   67,   74,   75,   76,
       77,   78,   79,   80,   81,   67,   67,   82,   67,   67,
       83,   84,   89,   92,   92,   92,   92,   92,   92,   92,
       92,   92,   92,   92,   92,   92,   92,   92,   92,   92,
       92,   92,   92,   92,   99,  326,   99,   99,   99,   99,
       99,   99,  141,  135,  156,   99,   90,  102,  100,  103,
      114,   99,  135,  104,  157,  105,  135,  115,  101,   93,
      106,  107,  108,  112,  111,  113,  109,   99,  116,  117,
      132,   99,  110,  118,  119,  119,  119,  119,  120,  118,
       99,  140,  136,  135,  135,  125,  142,  135,  137,  126,

      145,  121,  130,  127,  128,  122,  138,  129,  131,  135,
      272,  168,  123,  169,  171,   99,  135,  124,   89,  189,
      186,  135,  135,  135,  135,  172,  187,  373,  374,  194,
      143,  146,  146,  146,  146,  146,  146,  146,  146,  146,
      146,  146,  146,  146,  146,  150,  135,  144,  152,  151,
      147,   99,   90,   92,   92,   92,   92,   92,   92,   92,
      148,  146,  146,  146,  146,  146,  146,  146,  159,   99,
       99,   99,  160,  196,  161,   99,   99,  149,  135,  162,
      163,  164,   99,  195,   99,  165,   99,  214,  264,   99,
      199,  166,  193,  153,  153,  153,  153,  153,  153,  153,

      197,  223,  198,  200,  192,  210,  153,  219,  203,  265,
       97,  153,  153,  153,  153,  153,  153,  134,  134,  135,
      134,  134,  134,  134,  134,  134,  134,  134,  134,  134,
      134,  134,  134,  134,  154,  154,  154,  154,  154,  154,
      154,  155,  134,  134,  134,  134,  134,  154,  154,  134,
      134,  134,  154,  154,  154,  154,  154,  154,  154,  154,
      154,  154,  154,  154,  154,  154,  154,  154,  154,  154,
      154,  154,  154,  154,  154,  154,  134,  134,  174,  175,
      175,  175,  175,  176,  174,  181,   98,   98,   98,  182,
       99,  135,   99,  183,  184,   99,  177,  185,   88,   99,

      178,  209,  209,  209,  209,   99,   99,  179,   99,   99,
      201,   99,  180,   99,  190,  190,  190,  190,  190,  190,
      190,  211,  204,  202,  208,   99,  205,  217,   99,  212,
       99,  213,  216,   99,  227,  135,  220,   99,  215,  206,
      135,  221,  232,  135,  225,  207,  118,  118,  118,  118,
      118,  118,  118,   99,  218,  226,  224,  136,  135,  135,
      273,  242,  222,  137,   99,  142,  135,  244,  228,   99,
      255,  138,  256,  135,  243,  327,  141,  135,   99,  135,
      245,  147,  274,   99,   99,  144,  135,  135,  280,  233,
      135,  148,  229,  229,  229,  229,  229,  229,  229,  143,

      275,  146,  146,  146,  146,  146,  146,  146,  230,  231,
      234,  247,  277,   99,  296,  248,  144,  235,  235,  235,
      235,  235,  235,  235,  252,  252,  252,  252,  249,   99,
      235,  299,  286,   99,  250,  235,  235,  235,  235,  235,
      235,  236,  236,  236,  236,  236,  236,  236,  174,  174,
      174,  174,   99,   99,  236,   99,  270,  278,  283,  236,
      236,  236,  236,  236,  236,  174,  174,  174,  174,  174,
      174,  174,  190,  190,  190,  190,  190,  190,  190,   99,
      279,   99,   99,  291,  288,  281,  289,  282,  227,  135,
       99,  135,   99,  276,   99,  284,  285,  285,  285,  285,

      285,  285,   99,   99,  135,  292,  135,  317,  135,  318,
      287,  290,  290,  290,  290,  290,  290,  290,  135,  270,
      293,   99,  228,  324,  290,  294,  295,  135,  302,  290,
      290,  290,  290,  290,  290,  320,  334,   99,   99,  144,
      230,  298,  229,  229,  229,  229,  229,  229,  229,  328,
      303,  329,   99,  331,  297,  332,  135,  321,  341,   99,
      300,  301,  301,  301,  301,  301,  301,  301,  314,  314,
      314,  314,  314,  314,  301,  135,   99,  333,   99,  301,
      301,  301,  301,  301,  301,  319,  319,  319,  319,  319,
      319,  319,   99,  337,  335,  135,  338,  135,  319,   99,

      339,  135,   99,  319,  319,  319,  319,  319,  319,  295,
      135,  135,  342,  340,  351,  358,  352,  135,  363,  359,
       99,  330,  336,  336,  336,  336,  336,  336,  336,  364,
       99,   99,  135,  135,   99,  336,  369,   99,  135,  391,
      336,  336,  336,  336,  336,  336,  343,  135,  135,  135,
      135,  135,  344,  369,  373,  374,  393,  381,  366,  367,
      361,   99,  345,  346,  346,  346,  346,  346,  346,  346,
      372,  389,  386,  135,   99,  369,  346,   99,  383,  361,
      379,  346,  346,  346,  346,  346,  346,  356,  356,  356,
      356,  356,  356,  356,  378,  135,  370,  376,  375,  371,

      356,  135,  388,  135,  135,  356,  356,  356,  356,  356,
      356,  365,  365,  365,  365,  365,  365,  365,   99,   99,
       99,   99,   99,  392,  365,   99,  362,  361,  357,  365,
      365,  365,  365,  365,  365,  377,  377,  377,  377,  377,
      377,  377,  135,  355,  354,  353,  350,  349,  377,  348,
      347,  135,   99,  377,  377,  377,  377,  377,  377,  380,
      381,  382,   99,  361,   99,   99,   99,   99,   99,   99,
       99,  325,  323,  322,  316,  380,  380,  380,  380,  380,
      380,  380,  384,  384,  384,  384,  384,  384,  384,  315,
      313,  312,  311,  310,  309,  384,  308,  307,  306,  305,

      384,  384,  384,  384,  384,  384,  385,  386,  387,  304,
      369,   99,   99,   99,   99,   99,   99,   99,   99,   99,
       99,   99,  385,  385,  385,  385,  385,  385,  385,  390,
      390,  390,  390,  390,  390,  390,   99,   99,   99,  271,
      135,  269,  390,  268,  267,  266,  263,  390,  390,  390,
      390,  390,  390,  380,  381,  382,  262,  361,  261,  260,
      259,  258,  257,  254,  253,  251,  246,  241,  240,  380,
      380,  380,  380,  380,  380,  380,  385,  386,  387,  239,
      369,  238,  237,  135,  135,  135,  135,  135,  135,  135,
       99,   99,  385,  385,  385,  385,  385,  385,  385,  135,

       99,   99,   99,   99,  191,   85,  135,  188,  173,  170,
      167,  158,  135,  135,  135,  135,  135,  135,  135,  135,
      135,  135,  139,  135,  133,   99,   96,  394,  394,   95,
       94,   91,  394,  394,  394,  394,  394,  394,  394,  394,
      394,  394,  394,  394,  394,  394,  394,  394,  394,  394,
      394,  394,  394,  394,  394,  394,  134,  134,  135,  134,
      134,  134,  134,  134,  134,  134,  395,  134,  134,  134,
      134,  134,  134,  396,  396,  396,  396,  396,  396,  396,
      134,  134,  134,  134,  134,  134,  396,  396,  134,  134,
      134,  396,  396,  396,  396,  396,  396,  396,  396,  396,

      396,  396,  396,  396,  396,  396,  396,  396,  396,  396,
      396,  396,  396,  396,  396,  134,  134,   98,   98,  134,
      134,  134,  134,  360,   88,  360,  360,  368,  368,  368,
      368,   87,   86,   85,  397,    3,  397,  397,  397,  397,
      397,  397,  397,  397,  397,  397,  397,  397,  397,  397,
      397,  397,  397,  397,  397,  397,  397,  397,  397,  397,
      397,  397,  397,  397,  397,  397,  397,  397,  397,  397,
      397,  397,  397,  397,  397,  397,  397,  397,  397,  397,
      397,  397,  397,  397,  397,  397,  397,  397,  397,  397,
      397,  397,  397,  397,  397,  397,  397

    } ;

static yyconst flex_int16_t yy_chk[1198] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,

        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,   10,   17,   17,   17,   17,   17,   17,   17,
       19,   19,   19,   19,   19,   19,   19,   20,   20,   20,
       20,   20,   20,   20,   30,  404,   31,   33,   32,   35,
       34,   36,   49,   49,   71,   41,   10,   31,   30,   32,
       35,   37,   83,   32,   71,   32,   48,   36,   30,   19,
       32,   32,   32,   34,   33,   34,   32,   39,   36,   37,
       41,   40,   32,   38,   38,   38,   38,   38,   38,   38,
       38,   48,   45,   45,   51,   39,   50,   50,   45,   39,

       51,   38,   40,   39,   39,   38,   45,   39,   40,   58,
      403,   75,   38,   75,   77,  100,   57,   38,   89,   83,
       81,   63,   65,   60,   64,   77,   81,  345,  345,  100,
       50,   57,   57,   57,   57,   57,   57,   57,   60,   60,
       60,   60,   60,   60,   60,   63,   61,   50,   65,   64,
       58,  102,   89,   92,   92,   92,   92,   92,   92,   92,
       58,   61,   61,   61,   61,   61,   61,   61,   73,  101,
      104,  115,   73,  102,   73,  105,  103,   60,   66,   73,
       73,   73,  107,  101,  125,   73,  112,  115,  184,  129,
      105,   73,  402,   66,   66,   66,   66,   66,   66,   66,

      103,  129,  104,  105,  401,  112,   66,  125,  107,  184,
      398,   66,   66,   66,   66,   66,   66,   67,   67,   67,
       67,   67,   67,   67,   67,   67,   67,   67,   67,   67,
       67,   67,   67,   67,   67,   67,   67,   67,   67,   67,
       67,   67,   67,   67,   67,   67,   67,   67,   67,   67,
       67,   67,   67,   67,   67,   67,   67,   67,   67,   67,
       67,   67,   67,   67,   67,   67,   67,   67,   67,   67,
       67,   67,   67,   67,   67,   67,   67,   67,   79,   79,
       79,   79,   79,   79,   79,   80,  120,  120,  120,   80,
      113,  144,  110,   80,   80,  106,   79,   80,   88,  117,

       79,  111,  111,  111,  111,  114,  116,   79,  111,  127,
      106,  108,   79,  121,   88,   88,   88,   88,   88,   88,
       88,  113,  108,  106,  110,  122,  108,  121,  132,  114,
      128,  114,  117,  131,  137,  137,  127,  130,  116,  108,
      138,  128,  144,  147,  131,  108,  119,  119,  119,  119,
      119,  119,  119,  119,  122,  132,  130,  136,  136,  143,
      194,  161,  128,  136,  204,  142,  142,  162,  137,  194,
      170,  136,  170,  148,  161,  274,  141,  141,  196,  230,
      162,  138,  194,  198,  274,  137,  146,  395,  204,  147,
      233,  138,  141,  141,  141,  141,  141,  141,  141,  142,

      196,  146,  146,  146,  146,  146,  146,  146,  143,  143,
      148,  164,  198,  217,  230,  164,  142,  149,  149,  149,
      149,  149,  149,  149,  167,  167,  167,  167,  164,  199,
      149,  233,  217,  210,  164,  149,  149,  149,  149,  149,
      149,  153,  153,  153,  153,  153,  153,  153,  176,  176,
      176,  176,  201,  205,  153,  207,  190,  199,  210,  153,
      153,  153,  153,  153,  153,  175,  175,  175,  175,  175,
      175,  175,  190,  190,  190,  190,  190,  190,  190,  197,
      201,  212,  218,  223,  219,  205,  219,  207,  227,  227,
      219,  228,  223,  197,  224,  212,  214,  214,  214,  214,

      214,  214,  225,  214,  231,  223,  234,  262,  232,  262,
      218,  220,  220,  220,  220,  220,  220,  220,  296,  270,
      224,  275,  227,  270,  220,  225,  229,  229,  237,  220,
      220,  220,  220,  220,  220,  266,  288,  280,  288,  227,
      228,  232,  229,  229,  229,  229,  229,  229,  229,  275,
      237,  280,  286,  283,  231,  283,  388,  266,  296,  283,
      234,  236,  236,  236,  236,  236,  236,  236,  257,  257,
      257,  257,  257,  257,  236,  297,  384,  286,  293,  236,
      236,  236,  236,  236,  236,  263,  263,  263,  263,  263,
      263,  263,  281,  292,  289,  389,  293,  298,  263,  289,

      293,  299,  292,  263,  263,  263,  263,  263,  263,  295,
      295,  300,  297,  295,  312,  322,  312,  344,  331,  322,
      331,  281,  290,  290,  290,  290,  290,  290,  290,  332,
      338,  339,  371,  340,  332,  290,  340,  367,  372,  389,
      290,  290,  290,  290,  290,  290,  298,  342,  343,  392,
      368,  370,  299,  368,  373,  373,  392,  382,  338,  339,
      382,  366,  300,  301,  301,  301,  301,  301,  301,  301,
      344,  372,  387,  391,  364,  387,  301,  363,  362,  360,
      359,  301,  301,  301,  301,  301,  301,  319,  319,  319,
      319,  319,  319,  319,  358,  357,  342,  352,  351,  343,

      319,  347,  370,  346,  341,  319,  319,  319,  319,  319,
      319,  336,  336,  336,  336,  336,  336,  336,  335,  334,
      333,  330,  329,  391,  336,  328,  325,  324,  321,  336,
      336,  336,  336,  336,  336,  356,  356,  356,  356,  356,
      356,  356,  320,  318,  317,  315,  310,  309,  356,  304,
      303,  302,  294,  356,  356,  356,  356,  356,  356,  361,
      361,  361,  287,  361,  285,  284,  282,  279,  278,  277,
      276,  271,  268,  267,  261,  361,  361,  361,  361,  361,
      361,  361,  365,  365,  365,  365,  365,  365,  365,  260,
      255,  253,  250,  248,  247,  365,  244,  242,  241,  240,

      365,  365,  365,  365,  365,  365,  369,  369,  369,  239,
      369,  226,  222,  221,  216,  215,  213,  211,  209,  208,
      206,  203,  369,  369,  369,  369,  369,  369,  369,  377,
      377,  377,  377,  377,  377,  377,  202,  200,  195,  191,
      189,  188,  377,  187,  186,  185,  183,  377,  377,  377,
      377,  377,  377,  380,  380,  380,  181,  380,  178,  177,
      173,  172,  171,  169,  168,  166,  163,  160,  159,  380,
      380,  380,  380,  380,  380,  380,  385,  385,  385,  158,
      385,  157,  156,  155,  152,  151,  150,  145,  140,  134,
      126,  124,  385,  385,  385,  385,  385,  385,  385,  393,

      123,  118,  109,   98,   90,   85,   84,   82,   78,   76,
       74,   72,   70,   69,   68,   62,   59,   56,   55,   54,
       53,   52,   47,   44,   42,   26,   24,  393,  393,   23,
       22,   11,  393,  393,  393,  393,  393,  393,  393,  393,
      393,  393,  393,  393,  393,  393,  393,  393,  393,  393,
      393,  393,  393,  393,  393,  393,  394,  394,  394,  394,
      394,  394,  394,  394,  394,  394,  394,  394,  394,  394,
      394,  394,  394,  394,  394,  394,  394,  394,  394,  394,
      394,  394,  394,  394,  394,  394,  394,  394,  394,  394,
      394,  394,  394,  394,  394,  394,  394,  394,  394,  394,

      394,  394,  394,  394,  394,  394,  394,  394,  394,  394,
      394,  394,  394,  394,  394,  394,  394,  399,  399,  400,
      400,  400,  400,  405,    9,  405,  405,  406,  406,  406,
      406,    8,    7,    5,    3,  397,  397,  397,  397,  397,
      397,  397,  397,  397,  397,  397,  397,  397,  397,  397,
      397,  397,  397,  397,  397,  397,  397,  397,  397,  397,
      397,  397,  397,  397,  397,  397,  397,  397,  397,  397,
      397,  397,  397,  397,  397,  397,  397,  397,  397,  397,
      397,  397,  397,  397,  397,  397,  397,  397,  397,  397,
      397,  397,  397,  397,  397,  397,  397

    } ;

extern int yy_flex_debug;
int yy_flex_debug = 0;

static yy_state_type *yy_state_buf=0, *yy_state_ptr=0;
static char *yy_full_match;
static int yy_lp;
static int yy_looking_for_trail_begin = 0;
static int yy_full_lp;
static int *yy_full_state;
#define YY_TRAILING_MASK 0x2000
#define YY_TRAILING_HEAD_MASK 0x4000
#define REJECT \
{ \
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */ \
yy_cp = (yy_full_match); /* restore poss. backed-over text */ \
(yy_lp) = (yy_full_lp); /* restore orig. accepting pos. */ \
(yy_state_ptr) = (yy_full_state); /* restore orig. state */ \
yy_current_state = *(yy_state_ptr); /* restore curr. state */ \
++(yy_lp); \
goto find_rule; \
}

#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "scanner.l"
#line 2 "scanner.l"

/*
 *   Copyright (C) 2006-2010  Michael Buesch <mb@bu3sch.de>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License version 2
 *   as published by the Free Software Foundation.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 */

#include "parser.h"
#include "main.h"
#include "util.h"

#include <stdio.h>
#include <ctype.h>


static void interpret_cppinfo(const char *);
static void update_lineinfo(void);

static inline void log_current_line(void)
{
	size_t len;

	len = min(sizeof(cur_lineinfo.linecopy) - 1, strlen(yytext));
	memcpy(cur_lineinfo.linecopy, yytext, len);
	cur_lineinfo.linecopy[len] = '\0';
}

#line 958 "scanner.c"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy (void );

int yyget_debug (void );

void yyset_debug (int debug_flag  );

YY_EXTRA_TYPE yyget_extra (void );

void yyset_extra (YY_EXTRA_TYPE user_defined  );

FILE *yyget_in (void );

void yyset_in  (FILE * in_str  );

FILE *yyget_out (void );

void yyset_out  (FILE * out_str  );

int yyget_leng (void );

char *yyget_text (void );

int yyget_lineno (void );

void yyset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO fwrite( yytext, yyleng, 1, yyout )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	if ( yyleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(yytext[yyleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 42 "scanner.l"


#line 1146 "scanner.c"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

        /* Create the reject buffer large enough to save one state per allowed character. */
        if ( ! (yy_state_buf) )
            (yy_state_buf) = (yy_state_type *)yyalloc(YY_STATE_BUF_SIZE  );
            if ( ! (yy_state_buf) )
                YY_FATAL_ERROR( "out of dynamic memory in yylex()" );

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE );
		}

		yy_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();

		(yy_state_ptr) = (yy_state_buf);
		*(yy_state_ptr)++ = yy_current_state;

yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 398 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			*(yy_state_ptr)++ = yy_current_state;
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1136 );

yy_find_action:
		yy_current_state = *--(yy_state_ptr);
		(yy_lp) = yy_accept[yy_current_state];
find_rule: /* we branch to this label when backing up */
		for ( ; ; ) /* until we find what rule we matched */
			{
			if ( (yy_lp) && (yy_lp) < yy_accept[yy_current_state + 1] )
				{
				yy_act = yy_acclist[(yy_lp)];
				if ( yy_act & YY_TRAILING_HEAD_MASK ||
				     (yy_looking_for_trail_begin) )
					{
					if ( yy_act == (yy_looking_for_trail_begin) )
						{
						(yy_looking_for_trail_begin) = 0;
						yy_act &= ~YY_TRAILING_HEAD_MASK;
						break;
						}
					}
				else if ( yy_act & YY_TRAILING_MASK )
					{
					(yy_looking_for_trail_begin) = yy_act & ~YY_TRAILING_MASK;
					(yy_looking_for_trail_begin) |= YY_TRAILING_HEAD_MASK;
					(yy_full_match) = yy_cp;
					(yy_full_state) = (yy_state_ptr);
					(yy_full_lp) = (yy_lp);
					}
				else
					{
					(yy_full_match) = yy_cp;
					(yy_full_state) = (yy_state_ptr);
					(yy_full_lp) = (yy_lp);
					break;
					}
				++(yy_lp);
				goto find_rule;
				}
			--yy_cp;
			yy_current_state = *--(yy_state_ptr);
			(yy_lp) = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
case 1:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 44 "scanner.l"
{ log_current_line(); REJECT; }
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 45 "scanner.l"
{ interpret_cppinfo(yytext); }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 48 "scanner.l"
{ update_lineinfo(); /* whitespace */ }
	YY_BREAK
case 4:
/* rule 4 can match eol */
YY_RULE_SETUP
#line 49 "scanner.l"
{ cur_lineinfo.lineno++; update_lineinfo(); }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 51 "scanner.l"
{ update_lineinfo(); return ASM_ARCH; }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 52 "scanner.l"
{ update_lineinfo(); return ASM_START; }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 53 "scanner.l"
{ update_lineinfo(); return ASM_ASSERT; }
	YY_BREAK
case 8:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 55 "scanner.l"
{ update_lineinfo(); return SECTION_TEXT; }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 56 "scanner.l"
{ update_lineinfo(); return SECTION_IVALS; }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 58 "scanner.l"
{ update_lineinfo(); return SPR; }
	YY_BREAK
case 11:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 59 "scanner.l"
{ update_lineinfo(); return GPR; }
	YY_BREAK
case 12:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 3;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 60 "scanner.l"
{ update_lineinfo(); return OFFR; }
	YY_BREAK
case 13:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp = yy_bp + 2;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 61 "scanner.l"
{ update_lineinfo(); return LR; }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 63 "scanner.l"
{ update_lineinfo(); return COMMA; }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 64 "scanner.l"
{ update_lineinfo(); return SEMICOLON; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 65 "scanner.l"
{ update_lineinfo(); return BRACK_OPEN; }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 66 "scanner.l"
{ update_lineinfo(); return BRACK_CLOSE; }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 67 "scanner.l"
{ update_lineinfo(); return PAREN_OPEN; }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 68 "scanner.l"
{ update_lineinfo(); return PAREN_CLOSE; }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 70 "scanner.l"
{ update_lineinfo(); return EQUAL; }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 71 "scanner.l"
{ update_lineinfo(); return NOT_EQUAL; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 72 "scanner.l"
{ update_lineinfo(); return LOGICAL_OR; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 73 "scanner.l"
{ update_lineinfo(); return LOGICAL_AND; }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 74 "scanner.l"
{ update_lineinfo(); return PLUS; }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 75 "scanner.l"
{ update_lineinfo(); return MINUS; }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 76 "scanner.l"
{ update_lineinfo(); return MULTIPLY; }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 77 "scanner.l"
{ update_lineinfo(); return DIVIDE; }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 78 "scanner.l"
{ update_lineinfo(); return BITW_OR; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 79 "scanner.l"
{ update_lineinfo(); return BITW_AND; }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 80 "scanner.l"
{ update_lineinfo(); return BITW_XOR; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 81 "scanner.l"
{ update_lineinfo(); return BITW_NOT; }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 82 "scanner.l"
{ update_lineinfo(); return LEFTSHIFT; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 83 "scanner.l"
{ update_lineinfo(); return RIGHTSHIFT; }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 85 "scanner.l"
{ update_lineinfo(); return OP_ADD; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 86 "scanner.l"
{ update_lineinfo(); return OP_ADDSC; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 87 "scanner.l"
{ update_lineinfo(); return OP_ADDC; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 88 "scanner.l"
{ update_lineinfo(); return OP_ADDSCC; }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 90 "scanner.l"
{ update_lineinfo(); return OP_SUB; }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 91 "scanner.l"
{ update_lineinfo(); return OP_SUBSC; }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 92 "scanner.l"
{ update_lineinfo(); return OP_SUBC; }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 93 "scanner.l"
{ update_lineinfo(); return OP_SUBSCC; }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 95 "scanner.l"
{ update_lineinfo(); return OP_SRA; }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 96 "scanner.l"
{ update_lineinfo(); return OP_OR; }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 97 "scanner.l"
{ update_lineinfo(); return OP_AND; }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 98 "scanner.l"
{ update_lineinfo(); return OP_XOR; }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 99 "scanner.l"
{ update_lineinfo(); return OP_SR; }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 100 "scanner.l"
{ update_lineinfo(); return OP_SRX; }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 101 "scanner.l"
{ update_lineinfo(); return OP_SL; }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 102 "scanner.l"
{ update_lineinfo(); return OP_RL; }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 103 "scanner.l"
{ update_lineinfo(); return OP_RR; }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 104 "scanner.l"
{ update_lineinfo(); return OP_NAND; }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 105 "scanner.l"
{ update_lineinfo(); return OP_ORX; }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 106 "scanner.l"
{ update_lineinfo(); return OP_MOV; }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 108 "scanner.l"
{ update_lineinfo(); return OP_JMP; }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 109 "scanner.l"
{ update_lineinfo(); return OP_JAND; }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 110 "scanner.l"
{ update_lineinfo(); return OP_JNAND; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 111 "scanner.l"
{ update_lineinfo(); return OP_JS; }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 112 "scanner.l"
{ update_lineinfo(); return OP_JNS; }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 113 "scanner.l"
{ update_lineinfo(); return OP_JE; }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 114 "scanner.l"
{ update_lineinfo(); return OP_JNE; }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 115 "scanner.l"
{ update_lineinfo(); return OP_JLS; }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 116 "scanner.l"
{ update_lineinfo(); return OP_JGES; }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 117 "scanner.l"
{ update_lineinfo(); return OP_JGS; }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 118 "scanner.l"
{ update_lineinfo(); return OP_JLES; }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 119 "scanner.l"
{ update_lineinfo(); return OP_JL; }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 120 "scanner.l"
{ update_lineinfo(); return OP_JGE; }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 121 "scanner.l"
{ update_lineinfo(); return OP_JG; }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 122 "scanner.l"
{ update_lineinfo(); return OP_JLE; }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 123 "scanner.l"
{ update_lineinfo(); return OP_JZX; }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 124 "scanner.l"
{ update_lineinfo(); return OP_JNZX; }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 125 "scanner.l"
{ update_lineinfo(); return OP_JEXT; }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 126 "scanner.l"
{ update_lineinfo(); return OP_JNEXT; }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 128 "scanner.l"
{ update_lineinfo(); return OP_CALL; }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 129 "scanner.l"
{ update_lineinfo(); return OP_CALLS; }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 130 "scanner.l"
{ update_lineinfo(); return OP_RET; }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 131 "scanner.l"
{ update_lineinfo(); return OP_RETS; }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 133 "scanner.l"
{ update_lineinfo(); return OP_TKIPH; }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 134 "scanner.l"
{ update_lineinfo(); return OP_TKIPHS; }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 135 "scanner.l"
{ update_lineinfo(); return OP_TKIPL; }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 136 "scanner.l"
{ update_lineinfo(); return OP_TKIPLS; }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 138 "scanner.l"
{ update_lineinfo(); return OP_NAP; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 140 "scanner.l"
{ update_lineinfo(); return IVAL_MMIO16; }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 141 "scanner.l"
{ update_lineinfo(); return IVAL_MMIO32; }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 142 "scanner.l"
{ update_lineinfo(); return IVAL_PHY; }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 143 "scanner.l"
{ update_lineinfo(); return IVAL_RADIO; }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 144 "scanner.l"
{ update_lineinfo(); return IVAL_SHM16; }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 145 "scanner.l"
{ update_lineinfo(); return IVAL_SHM32; }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 146 "scanner.l"
{ update_lineinfo(); return IVAL_TRAM; }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 148 "scanner.l"
{ update_lineinfo(); return RAW_CODE; }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 150 "scanner.l"
{ update_lineinfo(); return HEXNUM; }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 151 "scanner.l"
{ update_lineinfo(); return DECNUM; }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 153 "scanner.l"
{ update_lineinfo(); return LABEL; }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 154 "scanner.l"
{ update_lineinfo(); return IDENT; }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 156 "scanner.l"
ECHO;
	YY_BREAK
#line 1749 "scanner.c"
			case YY_STATE_EOF(INITIAL):
				yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			YY_FATAL_ERROR(
"input buffer overflow, can't enlarge buffer because scanner uses REJECT" );

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	(yy_state_ptr) = (yy_state_buf);
	*(yy_state_ptr)++ = yy_current_state;

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 398 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		*(yy_state_ptr)++ = yy_current_state;
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    
	register YY_CHAR yy_c = 1;
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 398 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 397);
	if ( ! yy_is_jam )
		*(yy_state_ptr)++ = yy_current_state;

	return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp )
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register int number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf  );

	yyfree((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr )
{
    
	return yy_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
        
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void yyset_lineno (int  line_number )
{
    
    yylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str )
{
        yyin = in_str ;
}

void yyset_out (FILE *  out_str )
{
        yyout = out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  bdebug )
{
        yy_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

    (yy_state_buf) = 0;
    (yy_state_ptr) = 0;
    (yy_full_match) = 0;
    (yy_lp) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    yyfree ( (yy_state_buf) );
    (yy_state_buf)  = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr )
{
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 156 "scanner.l"



struct lineinfo cur_lineinfo;

static inline const char * strip_leading_ws(const char *str)
{
	while (*str != '\0' && isspace(*str))
		str++;
	return str;
}

static void interpret_cppinfo(const char *str)
{
	const char * const orig = str;
	char tmp[64];
	const char *found;
	char *tail;

	/* This will interpret lines added by CPP.
	 * They look like:
	 *     # lineno "filename" flags...
	 */

	str = strip_leading_ws(str);
	if (*str != '#')
		goto error;
	str++; /* skip # character */
	str = strip_leading_ws(str);
	if (*str == '\0')
		goto error;

	/* Line number */
	found = strchr(str, ' ');
	if (!found)
		goto error;
	memset(tmp, 0, sizeof(tmp));
	memcpy(tmp, str, min(sizeof(tmp) - 1, (size_t)(found - str)));
	cur_lineinfo.lineno = strtoul(tmp, &tail, 0);
	if (*tail != '\0')
		goto error;
	str = strip_leading_ws(found);

	/* File name */
	if (*str != '\"')
		goto error;
	str++;
	if (*str == '\0')
		goto error;
	found = strchr(str, '\"');
	if (!found)
		goto error;
	memset(cur_lineinfo.file, 0, sizeof(cur_lineinfo.file));
	memcpy(cur_lineinfo.file, str, min(sizeof(cur_lineinfo.file) - 1,
					   (size_t)(found - str)));

	/* We ignore the flags. */

	return;
error:
	fprintf(stderr, "Invalid CPP line directive:  %s\n", orig);
	exit(1);
}

static void update_lineinfo(void)
{
	int i = 0;

	while (yytext[i] != '\0') {
		switch (yytext[i]) {
		case '\r':
		case '\n':
			cur_lineinfo.column = 0;
			break;
		case '\t':
			cur_lineinfo.column += 8 - (cur_lineinfo.column % 8);
			break;
		default:
			cur_lineinfo.column++;
		}
		i++;
	}
}

